==> wagtail-wordpress-import-0.1.4.tar.gz: wagtail-wordpress-import-0.1.4/CHANGELOG.md <==
# Changelog

## Unreleased

---

## 0.1.4 [2022-01-27](https://github.com/torchbox/wagtail-wordpress-import/releases/tag/v0.1.4)

### Bugfixes

- Empty item title breaks import [#135](https://github.com/torchbox/wagtail-wordpress-import/pull/135)
- Issue/fatal error requests [#125](https://github.com/torchbox/wagtail-wordpress-import/pull/125)
- Support slash in file path in reduce command [#129](https://github.com/torchbox/wagtail-wordpress-import/pull/129) (Thanks [@fabienheureux](https://github.com/fabienheureux))
- Fix typo in wp:postmeta tag name [#131](https://github.com/torchbox/wagtail-wordpress-import/pull/131) (Thanks [@fabienheureux](https://github.com/fabienheureux))

### Features

- Upgrade lxml [#112](https://github.com/torchbox/wagtail-wordpress-import/pull/112)

### Documentation

- update README for issues raised [#126](https://github.com/torchbox/wagtail-wordpress-import/pull/126)
- PyPi link and docs [#127](https://github.com/torchbox/wagtail-wordpress-import/pull/127)
- Fix dead links in import hooks documentation [#132](https://github.com/torchbox/wagtail-wordpress-import/pull/132) (Thanks [@fabienheureux](https://github.com/fabienheureux))
- Update categories docs [#128](https://github.com/torchbox/wagtail-wordpress-import/pull/128)

---

## 0.1.3 [2021-12-13](https://github.com/torchbox/wagtail-wordpress-import/releases/tag/v0.1.3)

Our first public release.

### Bug Fixes

- Collect some test cases in the same TestCase class [#111](https://github.com/torchbox/wagtail-wordpress-import/pull/111)
- Fix Config overrides [#106](https://github.com/torchbox/wagtail-wordpress-import/pull/106)
- Refactor date getters [#109](https://github.com/torchbox/wagtail-wordpress-import/pull/109)

### Features

### Documentation

- Add coverage report [#105](https://github.com/torchbox/wagtail-wordpress-import/pull/105)
- Add import process flow diagram [#103](https://github.com/torchbox/wagtail-wordpress-import/pull/103)
- Example for image in anchor [#107](https://github.com/torchbox/wagtail-wordpress-import/pull/107)

---

0.1.2 [YANKED]

This realease was not published.

---

## 0.1.0 [2021-12-09](https://github.com/torchbox/wagtail-wordpress-import/releases/tag/v0.1.0)

First release: this was an initial trial release. Please use the latest version.

---

<!-- 
Template
## [x.y.z](https://github.com/torchbox/stylelint-config-torchbox/compare/va.b.c...vx.y.z) (YYYY-MM-DD)

### Bug Fixes

### Features

### Documentation

### BREAKING CHANGES 
-->

==> wagtail-wordpress-import-0.1.5.tar.gz: wagtail-wordpress-import-0.1.5/CHANGELOG.md <==
# Changelog

## Unreleased

## 0.1.5 [2022-02-14](https://github.com/torchbox/wagtail-wordpress-import/tree/v0.1.5)

### Bugfixes

- Category names that could be numbers [#151](https://github.com/torchbox/wagtail-wordpress-import/pull/151)

### Features

- Support wagtail 2.16 [#152](https://github.com/torchbox/wagtail-wordpress-import/pull/152)

### Documentation

---

## 0.1.4 [2022-01-27](https://github.com/torchbox/wagtail-wordpress-import/releases/tag/v0.1.4)

### Bugfixes

- Empty item title breaks import [#135](https://github.com/torchbox/wagtail-wordpress-import/pull/135)
- Issue/fatal error requests [#125](https://github.com/torchbox/wagtail-wordpress-import/pull/125)
- Support slash in file path in reduce command [#129](https://github.com/torchbox/wagtail-wordpress-import/pull/129) (Thanks [@fabienheureux](https://github.com/fabienheureux))
- Fix typo in wp:postmeta tag name [#131](https://github.com/torchbox/wagtail-wordpress-import/pull/131) (Thanks [@fabienheureux](https://github.com/fabienheureux))

### Features

- Upgrade lxml [#112](https://github.com/torchbox/wagtail-wordpress-import/pull/112)

### Documentation

- update README for issues raised [#126](https://github.com/torchbox/wagtail-wordpress-import/pull/126)
- PyPi link and docs [#127](https://github.com/torchbox/wagtail-wordpress-import/pull/127)
- Fix dead links in import hooks documentation [#132](https://github.com/torchbox/wagtail-wordpress-import/pull/132) (Thanks [@fabienheureux](https://github.com/fabienheureux))
- Update categories docs [#128](https://github.com/torchbox/wagtail-wordpress-import/pull/128)

---

## 0.1.3 [2021-12-13](https://github.com/torchbox/wagtail-wordpress-import/releases/tag/v0.1.3)

Our first public release.

### Bug Fixes

- Collect some test cases in the same TestCase class [#111](https://github.com/torchbox/wagtail-wordpress-import/pull/111)
- Fix Config overrides [#106](https://github.com/torchbox/wagtail-wordpress-import/pull/106)
- Refactor date getters [#109](https://github.com/torchbox/wagtail-wordpress-import/pull/109)

### Features

### Documentation

- Add coverage report [#105](https://github.com/torchbox/wagtail-wordpress-import/pull/105)
- Add import process flow diagram [#103](https://github.com/torchbox/wagtail-wordpress-import/pull/103)
- Example for image in anchor [#107](https://github.com/torchbox/wagtail-wordpress-import/pull/107)

---

0.1.2 [YANKED]

This realease was not published.

---

## 0.1.0 [2021-12-09](https://github.com/torchbox/wagtail-wordpress-import/releases/tag/v0.1.0)

First release: this was an initial trial release. Please use the latest version.

---

<!-- 
Template
## [x.y.z](https://github.com/torchbox/stylelint-config-torchbox/compare/va.b.c...vx.y.z) (YYYY-MM-DD)

### Bug Fixes

### Features

### Documentation

### BREAKING CHANGES 
-->
